@@ -119,11 +119,11 @@ def parse_args():
 def main():
     args = parse_args()
     if args.legacy:
-        master_path = (Path(apogee_data.__file__).absolute().parent.parent.parent
+        master_path = (Path(apogee_data.__file__).absolute().parent.parent
                        / 'dat/utr_master_flat_21180043.npy')
 
     else:
-        master_path = (Path(apogee_data.__file__).absolute().parent.parent.parent
+        master_path = (Path(apogee_data.__file__).absolute().parent.parent
                        / 'dat/master_dome_flat_1.npy')
     master_data = np.load(master_path)
 
